# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.2.1

([Full Changelog](https://github.com/juntyr/a-jupyterlite-query-config/compare/v0.2.0...8d654131a87ddcdf4922cf4a347a3c898068d372))

### Merged PRs

- Create devcontainer.json [#1](https://github.com/juntyr/a-jupyterlite-query-config/pull/1) ([@meechi44](https://github.com/meechi44), [@juntyr](https://github.com/juntyr))

### Contributors to this release

The following people contributed discussions, new ideas, code and documentation contributions, and review.
See [our definition of contributors](https://github-activity.readthedocs.io/en/latest/use/#how-does-this-tool-define-contributions-in-the-reports).

([GitHub contributors page for this release](https://github.com/juntyr/a-jupyterlite-query-config/graphs/contributors?from=2025-03-21&to=2026-05-11&type=c))

@juntyr ([activity](https://github.com/search?q=repo%3Ajuntyr%2Fa-jupyterlite-query-config+involves%3Ajuntyr+updated%3A2025-03-21..2026-05-11&type=Issues)) | @meechi44 ([activity](https://github.com/search?q=repo%3Ajuntyr%2Fa-jupyterlite-query-config+involves%3Ameechi44+updated%3A2025-03-21..2026-05-11&type=Issues))

<!-- <END NEW CHANGELOG ENTRY> -->

## 0.2.0

No merged PRs

## 0.1.0

No merged PRs
